==> haskell-edit-distance-0.2.2.1-282-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-GNOURkbBEJ122RiiY1tdSF
key:                  edit-distance-0.2.2.1-GNOURkbBEJ122RiiY1tdSF
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  3363f9f321f8394c9bedc4fa37989d93
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edit-distance
hs-libraries:         HSedit-distance-0.2.2.1-GNOURkbBEJ122RiiY1tdSF
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    random-1.2.1.3-BS01zQf871D7daMTFQ0UbO

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-edit-distance-0.2.2.1-283-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-edit-distance.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 edit-distance
version:              0.2.2.1
visibility:           public
id:                   edit-distance-0.2.2.1-G1LbOcc0JQWCWI2WfX0qpY
key:                  edit-distance-0.2.2.1-G1LbOcc0JQWCWI2WfX0qpY
license:              BSD-3-Clause
copyright:            (c) 2008-2013 Maximilian Bolinbroke
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:               Max Bolingbroke <batterseapower@hotmail.com>
homepage:             http://github.com/phadej/edit-distance
synopsis:
    Levenshtein and restricted Damerau-Levenshtein edit distances

description:
    Optimized edit distances for fuzzy matching, including Levenshtein and restricted Damerau-Levenshtein algorithms.

category:             Algorithms
abi:                  545a29b8b4a4d214a868f2d22710834e
exposed:              True
exposed-modules:      Text.EditDistance
hidden-modules:
    Text.EditDistance.EditCosts Text.EditDistance.SquareSTUArray
    Text.EditDistance.STUArray Text.EditDistance.Bits
    Text.EditDistance.MonadUtilities Text.EditDistance.ArrayUtilities

import-dirs:          /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/edit-distance-0.2.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-edit-distance
hs-libraries:         HSedit-distance-0.2.2.1-G1LbOcc0JQWCWI2WfX0qpY
depends:
    array-0.5.4.0 base-4.17.2.1 containers-0.6.7
    random-1.2.1.3-FjAccEVuGQcK7S7DSNXHmd

haddock-interfaces:
    /usr/share/doc/haskell-edit-distance/html/edit-distance.haddock

haddock-html:         /usr/share/doc/haskell-edit-distance/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
